import datetime
import time
t = datetime.datetime.now()
class CallSample:

        
        def ReturnMyVal():    
                    return 'Wole Olojede'
                    def ReturnCurrentTime():    
                                return  time.strftime("%H:%M:%S", time.localtime())
                                def ReturnCurrentDate():    
                                            return datetime.date
